@@ -1,40 +1,38 @@
-## ----eval=FALSE, include=TRUE--------------------------------------------
+## ---- eval=FALSE---------------------------------------------------------
+#  install.packages("benchmarkme")
+
+## ----eval=FALSE----------------------------------------------------------
 #  library("benchmarkme")
+#  ## Increase runs if you have a higher spec machine
 #  res = benchmark_std(runs = 3)
 
-## ----eval=FALSE----------------------------------------------------------
-#  id = upload_results(res)
-
-## ------------------------------------------------------------------------
-data(past_results, package="benchmarkmeData")
-
-## ------------------------------------------------------------------------
-head(past_results, 3)
-
-## ---- fig.width=7, fig.height=3.5, message=FALSE-------------------------
-## shine() # if you have shiny
-plot_past()
-
-## ---- fig.width=7, fig.height=3.5, message=FALSE, results="hide"---------
-plot(res)
+## ---- eval=FALSE---------------------------------------------------------
+#  ## You can control exactly what is uploaded. See details below.
+#  upload_results(res)
 
 ## ----eval=FALSE----------------------------------------------------------
-#  install.packages("DT")
+#  plot(res)
+
+## ---- eval=FALSE---------------------------------------------------------
+#  create_bundle(res, filename = "results.rds")
 
 ## ----eval=FALSE----------------------------------------------------------
-#  ## Your result is highlighted in orange.
-#  get_datatable(res)
-#  get_datatable_past()
-
-## ----eval=FALSE----------------------------------------------------------
-#  res_io = benchmark_io()
+#  res_io = benchmark_std(runs = 3)
 #  upload_results(res_io)
-#  ## Sample size is small, so don't split by byte/blas
-#  plot(res_io, byte_optimize=NULL, blas_optimize=NULL)
+#  plot(res_io)
+
+## ----eval=FALSE----------------------------------------------------------
+#  tempdir()
 
 ## ----eval=FALSE----------------------------------------------------------
 #  Sys.getenv("TMPDIR")
 
 ## ----eval=FALSE----------------------------------------------------------
-#  res_io = benchmark_io(tmpdir="some_other_directory")
+#  res_io = benchmark_io(tmpdir = "some_other_directory")
+
+## ------------------------------------------------------------------------
+data(past_results, package = "benchmarkmeData")
+
+## ----eval=FALSE----------------------------------------------------------
+#  upload_results(res, args = list(sys_info=FALSE))
 
